@@ -1,5 +1,8 @@
 /*
- *  $Id: defFind.c,v 4.8 2006/06/24 23:36:07 bkorb Exp $
+ *  $Id: defFind.c,v 4.12 2006/11/27 01:52:22 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-09-23 19:55:01 bkorb"
+ *  Last Committed:    $Date: 2006/11/27 01:52:22 $
  *
  *  This module locates definitions.
  */
@@ -34,7 +37,7 @@ typedef struct defEntryList tDefEntryList;
 
 tSCC zNameRef[]   = "Ill formed name ``%s'' in %s line %d\n";
 
-static char zDefinitionName[ MAXPATHLEN ];
+static char zDefinitionName[ AG_PATH_MAX ];
 
 static tDefEntry* findEntryByIndex( tDefEntry* pE, char* pzScan );
 
@@ -52,7 +55,7 @@ static void
 addResult( tDefEntry* pDE, tDefEntryList* pDEL );
 
 static size_t
-badName( char* pzD, const char* pzS, size_t srcLen );
+badName( char* pzD, char const* pzS, size_t srcLen );
 
 static tDefEntry*
 defEntrySearch( char* pzName, tDefCtx* pDefCtx, ag_bool* pIsIndexed );
@@ -106,7 +109,7 @@ findEntryByIndex( tDefEntry* pE, char* pzScan )
          *  '[XX]' means get the index from our definitions
          */
         char* pzDef = pzScan;
-        const char* pzVal;
+        char const* pzVal;
 
         if (! isalpha( *pzScan ))
             return NULL;
@@ -182,7 +185,7 @@ addResult( tDefEntry* pDE, tDefEntryList* pDEL )
 
 
 static size_t
-badName( char* pzD, const char* pzS, size_t srcLen )
+badName( char* pzD, char const* pzS, size_t srcLen )
 {
     memcpy( (void*)pzD, (void*)pzS, srcLen );
     pzD[ srcLen ] = NUL;
@@ -203,7 +206,7 @@ badName( char* pzD, const char* pzS, size_t srcLen )
  *  We start in CN_START.
  */
 LOCAL int
-canonicalizeName( char* pzD, const char* pzS, int srcLen )
+canonicalizeName( char* pzD, char const* pzS, int srcLen )
 {
     typedef enum {
         CN_START_NAME = 0,   /* must find a name */
@@ -215,7 +218,7 @@ canonicalizeName( char* pzD, const char* pzS, int srcLen )
 
     teConState state = CN_START_NAME;
 
-    const char* pzOri = pzS;
+    char const* pzOri = pzS;
     char*       pzDst = pzD;
     size_t      stLen = srcLen;
 
@@ -752,7 +755,6 @@ findEntryList( char* pzName )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/defFind.c */
