@@ -1,13 +1,17 @@
 
 /*
  *  expState.c
- *  $Id: expState.c,v 4.12 2006/07/22 04:50:19 bkorb Exp $
+ *  $Id: expState.c,v 4.20 2007/02/04 17:44:12 bkorb Exp $
+ *
+ *  Time-stamp:        "2007-02-03 08:13:52 bkorb"
+ *  Last Committed:    $Date: 2007/02/04 17:44:12 $
+ *
  *  This module implements expression functions that
  *  query and get state information from AutoGen data.
  */
 
 /*
- *  AutoGen copyright 1992-2006 Bruce Korb
+ *  AutoGen copyright 1992-2007 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -226,14 +230,22 @@ ag_scm_base_name( void )
  * what:   compare two version numbers
  * general_use:
  *
- * exparg: op, comparison operation
+ * exparg: op, comparison operator
  * exparg: v1, first version
  * exparg: v2, compared-to version
  *
  * doc:  Converts v1 and v2 strings into 64 bit values and returns the
  *       result of running 'op' on those values.  It assumes that the version
  *       is a 1 to 4 part dot-separated series of numbers.  Suffixes like,
- *       "5pre5" are presumed to be equal to the initial digits, e.g. "5".
+ *       "5pre4" or "5-pre4" will be interpreted as two numbers.  The first
+ *       number ("5" in this case) will be decremented and the number after
+ *       the "pre" will be added to 0xC000.  (Unless your platform is unable
+ *       to support 64 bit integer arithmetic.  Then it will be added to 0xC0.)
+ *       Consequently, these yield true:
+ *       @example
+ *       (version-compare > "5.8.5"       "5.8.5-pre4")
+ *       (version-compare > "5.8.5-pre10" "5.8.5-pre4")
+ *       @end example
 =*/
 static ver_type_t
 str2int_ver( char* pz )
@@ -277,7 +289,8 @@ str2int_ver( char* pz )
     } leave_str2int_ver: ;
 
     while (--ix >= 0)  val <<= VER_UNIT_SHIFT;
-    fprintf( pfTrace, "0x%016llX <<== '%s'\n", (long long)val, pzStr );
+    if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
+        fprintf( pfTrace, "0x%016llX <<== '%s'\n", (long long)val, pzStr );
     return val;
 }
 
@@ -478,7 +491,7 @@ ag_scm_get( SCM agName, SCM altVal )
     if ((pE == NULL) || (pE->valType != VALTYP_TEXT)) {
         if (AG_SCM_STRING_P( altVal ))
             return altVal;
-        return AG_SCM_STR02SCM( "" );
+        return AG_SCM_STR02SCM(zNil);
     }
 
     return AG_SCM_STR02SCM( pE->val.pzText );
@@ -522,12 +535,12 @@ ag_scm_high_lim( SCM obj )
         return AG_SCM_INT2SCM( 0 );
 
     if (isIndexed)
-        return AG_SCM_INT2SCM( pE->index );
+        return AG_SCM_INT2SCM( (int)pE->index );
 
     if (pE->pEndTwin != NULL)
         pE = pE->pEndTwin;
 
-    return AG_SCM_INT2SCM( pE->index );
+    return AG_SCM_INT2SCM( (int)pE->index );
 }
 
 
@@ -546,9 +559,7 @@ ag_scm_high_lim( SCM obj )
 SCM
 ag_scm_len( SCM obj )
 {
-    int         len;
-
-    len = entry_length( ag_scm2zchars( obj, "ag value" ));
+    int len = entry_length( ag_scm2zchars( obj, "ag value" ));
 
     return AG_SCM_INT2SCM( len );
 }
@@ -578,7 +589,7 @@ ag_scm_low_lim( SCM obj )
     if (pE == NULL)
         return AG_SCM_INT2SCM( 0 );
 
-    return AG_SCM_INT2SCM( pE->index );
+    return AG_SCM_INT2SCM( (int)pE->index );
 }
 
 
@@ -629,8 +640,8 @@ ag_scm_tpl_file( SCM full )
 {
     if (AG_SCM_BOOL_P( full ) && SCM_NFALSEP( full )) {
         tSCC* sfx[] = { "tpl", NULL };
-        char z[MAXPATHLEN];
-        if (SUCCESSFUL( findFile( pzTemplFileName, z, sfx )))
+        char z[AG_PATH_MAX];
+        if (SUCCESSFUL( findFile( pzTemplFileName, z, sfx, NULL )))
             return AG_SCM_STR02SCM( z );
     }
 
@@ -767,7 +778,6 @@ ag_scm_def_file_line( SCM obj, SCM fmt )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/expState.c */
