@@ -1,35 +1,42 @@
 #! /bin/sh
+set -x
 ## mkpkg.sh --      create a native package
-## Copyright (c):   2003-2006 by Bruce Korb
-## Time-stamp:      "2006-12-10 12:14:12 bkorb"
+## Copyright (c):   2003-2007 by Bruce Korb
+## Time-stamp:      "2007-02-04 10:27:47 bkorb"
 ## Maintainer:      Bruce Korb <bkorb@gnu.org>
 ## Created:         Sun Jul 28 20:37 2002
 ##              by: bkorb
 ## ---------------------------------------------------------------------
-## $Id: mkpkg.sh,v 4.5 2006/12/10 20:10:28 bkorb Exp $
+## $Id: mkpkg.sh,v 4.6 2007/02/04 18:51:52 bkorb Exp $
 ## ---------------------------------------------------------------------
 ## Code:
 
-if [ -z "${pkgtype}" ]
+test -f pkg-env && . pkg-env
+
+if test -z "${pkgtype}"
 then
-  pkgtype=`sh ${top_srcdir}/config/config.guess | \
-           sed 's,-[^-]*$,,;s,.*-,,'`
+  if fakeroot dh_testroot 2>/dev/null 2>&1
+  then pkgtype=debian
+  else pkgtype=`sh ${top_srcdir}/config/config.guess | \
+                sed 's,-[^-]*$,,;s,.*-,,'`
+  fi
 fi
 
-if [ -f ${srcdir}/mkpkg.${pkgtype} ]
+if test ! -f ${srcdir}/mkpkg.${pkgtype}
 then
-  . ${srcdir}/mkpkg.${pkgtype} || exit 1
-else
-  pkgtype=`uname -s | tr 'A-Z' 'a-z'`
+  pkgtype=`uname -s | tr '[A-Z]' '[a-z]'`
   test -f ${srcdir}/mkpkg.${pkgtype} || {
     echo "No mkpkg script for ${pkgtype}" >&2
     exit 1
   }
-  . ${srcdir}/mkpkg.${pkgtype} || exit 1
 fi
 
+. ${srcdir}/mkpkg.${pkgtype}
+
 ## Local Variables:
 ## mode: shell-script
 ## indent-tabs-mode: nil
+## sh-indentation: 2
+## sh-basic-offset: 2
 ## End:
 ## mkpkg.sh ends here
